// components/scheduler/include/scheduler.h
#pragma once

#include <stdbool.h>
#include <stdint.h>
#include "scheduler_types.h"

#ifdef __cplusplus
extern "C"
{
#endif

    void scheduler_init(void);
    void scheduler_set_config(const sched_config_t *cfg);
    sched_config_t scheduler_get_config(void);

    bool scheduler_is_allowed_now(void);
    uint16_t scheduler_get_current_limit_now_a(void);

#ifdef __cplusplus
}
#endif